@@ -85,9 +85,9 @@ from dyntapy.demand import (
     build_internal_dynamic_demand,
 )
 from dyntapy.demand_data import _check_centroid_connectivity
-from dyntapy.dta.aon import aon
 from dyntapy.dta.i_ltm_aon import i_ltm_aon
 from dyntapy.dta.incremental_assignment import incremental
+from dyntapy.sta.dial_stochastic_assignment import dial_sue
 from dyntapy.sta.dial_b import dial_b
 from dyntapy.sta.msa import msa_flow_averaging
 from dyntapy.sta.uncongested_dial import sun
@@ -137,7 +137,7 @@ class DynamicAssignment:
         Parameters
         ----------
 
-        method: {'i_ltm_aon','incremental_assignment', 'aon'}
+        method: {'i_ltm_aon','incremental_assignment'}
 
         Returns
         -------
@@ -159,7 +159,6 @@ class DynamicAssignment:
         'incremental_assignment' assigns the demands in chunks and updates the
         both costs and route choice after each DNL.
 
-        'aon' simply assigns all demand at free flow costs and executes one DNL.
 
         References
         ----------
@@ -185,9 +184,11 @@ class DynamicAssignment:
         methods = {
             "i_ltm_aon": i_ltm_aon,
             "incremental_assignment": incremental,
-            "aon": aon,
         }
         if method in methods:
+            # check for turn connectors, they are required since this algorithm
+            # is defined on the line graph
+            assert _turn_connectors(self.internal_network)
             result = methods[method](
                 self.internal_network, self.internal_dynamic_demand, self.time
             )
@@ -229,13 +230,13 @@ class StaticAssignment:
         log("Assignment object initialized!")
         print("init passed successfully")
 
-    def run(self, method, store_iterations=False):
+    def run(self, method, store_iterations=False, **kwargs):
         """
 
         Parameters
         ----------
 
-        method : {'dial_b','frank_wolfe', 'msa', 'sun'}
+        method : {'dial_b', 'msa', 'sun', 'sue'}
         store_iterations : bool
             set to True to get information on the individual iterations
 
@@ -249,17 +250,15 @@ class StaticAssignment:
         Notes
         -----
 
-        'msa', 'frank_wolfe' and 'dial_b' all try to find the static deterministic
+        'msa' and 'dial_b' try to find the static deterministic
         user equilibrium.
 
         'msa' refers to the Method of Successive Averages, a well known method in
         Traffic Assignments that tends to zig-zag around equilibrium.
 
-        'frank_wolfe' refers to the Frank-Wolfe Algorithm.
 
         'dial_b' refers to Dial's Algorithm B, a bush-based assignment
-        algorithm. It alleviates the rather slow convergence of the Frank-Wolfe
-        algorithm close to equilibrium, see [3]_.
+        algorithm [3]_. 
 
         'sun' returns a stochastic uncongested assignment of flows on the free-flow
         travel times that are determined by the lengths and speeds of the links. It
@@ -267,7 +266,7 @@ class StaticAssignment:
         and rests the definition of 'efficient links' to allow for computations on an
         acyclic graph.
 
-        'sun', 'frank_wolfe' and 'msa' are included for educational use.
+        'sun' and 'msa' are included for educational use.
 
         'dial_b' has been optimized and converges quickly even for
         large networks with thousands of links.
@@ -333,6 +332,22 @@ class StaticAssignment:
                 skim=get_skim(costs, self.internal_demand, self.internal_network),
                 origin_flows=origin_flows,
             )
+        elif method == "sue":
+            assert not store_iterations  # not supported for SUE yet
+            # check for turn connectors, they are required since this algorithm
+            # is defined on the line graph
+            assert _turn_connectors(self.internal_network)
+            costs, flows, destination_flows = dial_sue(
+                network=self.internal_network, demand=self.internal_demand, **kwargs
+            )
+            result = StaticResult(
+                costs,
+                flows,
+                self.internal_demand.origins,
+                self.internal_demand.destinations,
+                skim=get_skim(costs, self.internal_demand, self.internal_network),
+                destination_flows=destination_flows,
+            )
 
         else:
             raise NotImplementedError(f"{method=} is not defined ")
@@ -340,3 +355,15 @@ class StaticAssignment:
             return result
         else:
             return result, dyntapy._context.iteration_states
+
+
+def _turn_connectors(network):
+    # whether the network has turn connectors
+    # just a basic check for a single centroid/ connector combo
+    origin = 0
+    link = network.nodes.out_links.get_nnz(origin)[0]
+    next_link = network.links.out_turns.get_row(link)[0]
+    if network.links.link_type[next_link] == 1:
+        return True
+    else:
+        return False
