@@ -99,7 +99,12 @@ def build_internal_static_demand(od_graph: nx.DiGraph):
     dyntapy.demand.InternalStaticDemand
 
     """
-    lil_demand = nx.to_scipy_sparse_matrix(od_graph, weight="flow", format="lil")
+    try:
+        # available since networkx version 2.7.0, February 2022
+        lil_demand = nx.to_scipy_sparse_array(od_graph, weight="flow", format="lil")
+    except AttributeError:
+        # will be deprecated for networkx 3.0
+        lil_demand = nx.to_scipy_sparse_matrix(od_graph, weight="flow", format="lil")
     tot_centroids = od_graph.number_of_nodes()
     row = np.asarray(lil_demand.nonzero()[0])
     col = np.asarray(lil_demand.nonzero()[1])
@@ -376,7 +381,8 @@ def build_internal_dynamic_demand(
     ]
 
     if not np.all(
-        insertion_times[1:] - insertion_times[:-1] > simulation_time.step_size
+        dynamic_demand.insertion_times[1:] - dynamic_demand.insertion_times[:-1] >=
+        simulation_time.step_size
     ):
         raise ValueError(
             "insertion times are assumed to be monotonously increasing."
@@ -384,7 +390,7 @@ def build_internal_dynamic_demand(
             "two "
             "insertions is the internal simulation time step"
         )
-    if max(insertion_times > 24):
+    if max(dynamic_demand.insertion_times > 24):
         raise ValueError("internally time is restricted to 24 hours")
 
     static_demands = List()
