@@ -6,27 +6,32 @@
 #
 #
 #
+"""
+
+after initializing either a `dyntapy.assignments.StaticAssignment` or
+`dyntapy.assignments.DynamicAssignment` we have access to a compiled
+`dyntapy.supply.Network` object.
+Alternatively, this can be build using `dyntapy.supply_data.build_network`
+
+>>> network = dyntapy.supply_data.build_network(g)
+
+The structure of this network object is described below.
+It gives access to a Links, Nodes and Turns object such that one can easily retrieve
+any network information rather intuitively.
+
+For example, if one wanted to get the free flow travel times for all links,
+simply query the underlying links object.
+
+>>> free_flow_costs = network.links.length/network.links.free_speed
+
+"""
 from collections import OrderedDict
 
-import numpy as np
 from numba.core.types import boolean, float32, int8, uint8, uint32
-from numba.core.types.containers import ListType
 from numba.experimental import jitclass
 
 from dyntapy.csr import UI32CSRMatrix, f32csr_type, ui32csr_type
 
-# We differentiate here between the generic Links Nodes and Turns object and more
-# specialized objects that inherit from these classes Dynamic Traffic Assignment
-# algorithms all use a base line of attributes that are kept in these baseline
-# classes Algorithms like LTM need additional attributes - these are kept in objects
-# that inherit from their respective class, so LTM has a special class for its links
-# to store things like cvn .. the source code for the baseline classes is replicated
-# both in jitclass decorated and undecorated (uncompiled) form because inheritance
-# otherwise does not work at this point,
-# see https://github.com/numba/numba/issues/1694 . adding a new assignment algorithm
-# to this is meant to be made simpler this way, nothing changes in the assignment
-# object one simply needs to define new extending network, turn, node and link
-# objects as needed and write a setup file, as shown for i-ltm.
 
 spec_link = [
     ("capacity", float32[:]),
@@ -48,8 +53,37 @@ spec_link = [
 @jitclass(spec_link)
 class Links(object):
     """
-    A simple class that carries various arrays and CSR Matrices that have link ids as
-    their index
+    specifies internal Links object
+
+    Parameters
+    ----------
+    length: numpy.ndarray
+        float, 1D
+    from_node: numpy.ndarray
+        int, 1D
+    to_node: numpy.ndarray
+        int, 1D
+    capacity: numpy.ndarray
+        float, 1D
+    free_speed: numpy.ndarray
+        float, 1D
+    out_turns: dyntapy.csr.UI32CSRMatrix
+    in_turns: dyntapy.csr.UI32CSRMatrix
+    lanes: numpy.ndarray
+        int, 1D
+    link_type: numpy.ndarray
+        int, 1D
+
+    Notes
+    -----
+
+    should not be initialized by the user, use dyntapy.supply_data.build_network
+
+    `out_turns` and `in_turns` are sparse matrices in CSR format that indicate
+    connected turns and their links.
+    Both have the same shape (`network.tot_turns`, `network.tot_links`) with the
+    indexes indicating the link_id and the values the to- and from_link, respectively.
+    There's duplication to avoid on-the-fly transformations.
     """
 
     def __init__(
@@ -70,13 +104,12 @@ class Links(object):
         self.from_node = from_node
         self.free_speed = free_speed
         self.out_turns = out_turns  # csr link x turns row is outgoing
-        # links
         self.in_turns = in_turns  # csr incoming turns
         self.lanes = lanes
         self.link_type = link_type
 
 
-class UncompiledLinks(object):
+class _UncompiledLinks(object):
     """
     See Links class for docs
     """
@@ -123,8 +156,37 @@ spec_node = [
 @jitclass(spec_node)
 class Nodes(object):
     """
-    A simple class that carries various arrays and CSR Matrices that have node ids as
-    their index
+    specifies internal Nodes object
+
+    Parameters
+    ----------
+    out_links: dyntapy.csr.UI32CSRMatrix
+    in_links: dyntapy.csr.UI32CSRMatrix
+    tot_out_links: numpy.ndarray
+        int, 1D - number of outgoing links
+    tot_in_links: numpy.ndarray
+        int, 1D - number of outgoing links
+    control_type: numpy.ndarray
+        int, 1D
+    capacity: numpy.ndarray
+        float, 1D
+    is_centroid: numpy.ndarray
+        bool, 1D
+    x_coord: numpy.ndarray
+        float, 1D
+    y_coord: numpy.ndarray
+        float, 1D
+    Notes
+    -----
+
+    should not be initialized by the user, use dyntapy.supply_data.build_network
+
+    `out_links` and `in_links` are sparse matrices in CSR format that indicate
+    connected links and their nodes.
+    Both have the same shape (`network.tot_nodes`, `network.tot_links`) with the
+    indexes indicating the link_id and the values the to- and from_node, respectively.
+    There's duplication to avoid on-the-fly transformations.
+
     """
 
     def __init__(
@@ -139,28 +201,18 @@ class Nodes(object):
         x_coord,
         y_coord,
     ):
-        """
-        out_links and in_links are sparse matrices in csr format that indicate
-        connected links and their nodes
-        both are nodes x links with f(i,link_id) = j and essentially carry the same
-        information. There's duplication to
-        avoid on-the-fly transformations.
-        out_links is fromNode x Link and in_links toNode x Link in dim with toNode
-        and fromNode as val, respectively.
-        """
-        self.out_links: UI32CSRMatrix = out_links
+        self.out_links = out_links
         self.in_links: UI32CSRMatrix = in_links
         self.tot_out_links = tot_out_links
         self.tot_in_links = tot_in_links
-        # self.turn_fractions = turn_fractions  # node x turn_ids
-        self.control_type = control_type  #
+        self.control_type = control_type
         self.capacity = capacity
         self.is_centroid = is_centroid
         self.x_coord = x_coord
         self.y_coord = y_coord
 
 
-class UncompiledNodes(object):
+class _UncompiledNodes(object):
     """
     See Nodes class for docs
     """
@@ -209,8 +261,34 @@ spec_turn = OrderedDict(spec_turn)
 @jitclass(spec_turn)
 class Turns(object):
     """
-    A simple class that carries various arrays and CSR Matrices that have turn ids as
-    their index
+
+    specifies internal Turns object
+    should not be initialized by the user, use dyntapy.supply_data.build_network
+
+    Parameters
+    ----------
+    penalty: numpy.ndarray
+        float, 1D
+    capacity: numpy.ndarray
+        float, 1D
+    from_node: numpy.ndarray
+        int, 1D
+    via_node: numpy.ndarray
+        int, 1D
+    to_node: numpy.ndarray
+        int, 1D
+    from_link: numpy.ndarray
+        int, 1D
+    to_link: numpy.ndarray
+        int, 1D
+    turn_type: numpy.ndarray
+        int, 1D
+
+    Notes
+    -----
+
+    should not be initialized by the user, use dyntapy.supply_data.build_network
+
     """
 
     # db_restrictions refer to destination based restrictions as used in recursive logit
@@ -251,7 +329,30 @@ except Exception:
 
 @jitclass(spec_network)
 class Network(object):
-    # link mat
+    """
+    specifies internal Network object
+
+    Parameters
+    ----------
+    links: Links
+    nodes: Nodes
+    turns: Turns
+
+    Notes
+    -----
+
+    should be initialized with dyntapy.supply_data.build_network
+
+    See Also
+    --------
+    dyntapy.supply_data.build_network
+    dyntapy.supply.Links
+    dyntapy.supply.Nodes
+    dyntapy.supply.Turns
+
+
+    """
+
     def __init__(self, links, nodes, turns, tot_links, tot_nodes, tot_turns):
         self.links: Links = links
         self.nodes: Nodes = nodes
@@ -272,7 +373,7 @@ except Exception:
     spec_uncompiled_network = []
 
 
-class UncompiledNetwork(object):
+class _UncompiledNetwork(object):
     def __init__(self, links, nodes, turns, tot_links, tot_nodes, tot_turns):
         self.links = links
         self.nodes = nodes
@@ -280,4 +381,3 @@ class UncompiledNetwork(object):
         self.tot_links = tot_links
         self.tot_nodes = tot_nodes
         self.tot_turns = tot_turns
-        # TODO: add lookup tables for name to index
