@@ -12,6 +12,7 @@
 import datetime
 import os
 import warnings
+from itertools import chain
 from inspect import signature
 from warnings import warn
 
@@ -22,15 +23,14 @@ from bokeh.io import output_file, output_notebook, show
 from bokeh.layouts import Spacer, column, row
 from bokeh.models import HoverTool, OpenURL, TapTool
 from bokeh.models.callbacks import CustomJS
-from bokeh.models.glyphs import Patches
+from bokeh.models.glyphs import Patches, MultiPolygons
 from bokeh.models.markers import Circle
 from bokeh.models.widgets import Slider, TextInput
 from bokeh.plotting import ColumnDataSource, figure
 from bokeh.tile_providers import Vendors, get_provider
 from pyproj import CRS
-from shapely.geometry import LineString
+from shapely.geometry import LineString, MultiPolygon
 
-from dyntapy.demand import SimulationTime
 from dyntapy.settings import parameters
 from dyntapy.utilities import __create_green_to_red_cm
 
@@ -43,6 +43,8 @@ centroid_color = parameters.visualization.centroid_color
 node_size = parameters.visualization.node_size
 
 
+# TODO: investigate reactions on layout width changes,
+#  https://github.com/bokeh/bokeh/pull/6021
 def _get_output_file(plot_name: str):
     dt_string = datetime.datetime.now().strftime("%d_%m_%Y_%H_%M_%S")
     return os.getcwd() + os.path.sep + f"{plot_name}_{dt_string}.html"
@@ -91,7 +93,10 @@ def _process_plot_arguments(g, title, notebook, euclidean, link_kwargs, node_kwa
             tmp, CRS.from_user_input(3857)
         )  # from lan lot to web mercator
 
+        link_width_scaling = parameters.visualization.link_width_scaling
     else:
+
+        link_width_scaling = parameters.visualization.link_width_scaling_euclidean
         plot = figure(
             plot_height=parameters.visualization.plot_size,
             plot_width=parameters.visualization.plot_size,
@@ -129,7 +134,7 @@ def _process_plot_arguments(g, title, notebook, euclidean, link_kwargs, node_kwa
                 )
             else:
                 node_kwargs[key] = item.tolist()
-    return plot, tmp
+    return plot, tmp, link_width_scaling
 
 
 def show_network(
@@ -144,6 +149,7 @@ def show_network(
     title=None,
     notebook=False,
     show_nodes=True,
+    return_plot=False,
 ):
     """
     Visualizing a network with static attributes in a .html.
@@ -163,7 +169,7 @@ def show_network(
     highlight_links: numpy.ndarray or list, optional
         int, 1D or 2D - links to highlight
     highlight_nodes: numpy.ndarray or list, optional
-        int, 1D or 2D - links to highlight
+        int, 1D or 2D - nodes to highlight
     euclidean: bool, optional
         set to True if coordinates in graph are euclidean.
     toy_network: bool, optional
@@ -173,6 +179,8 @@ def show_network(
         set to True if the plot should be rendered in a notebook.
     show_nodes: bool, optional
         whether to render nodes
+    return_plot: bool, optional
+        set to True if the plot object should be returned instead of showing it.
 
     Examples
     --------
@@ -216,8 +224,7 @@ def show_network(
             "use of toy_network arg is deprecated, use euclidean instead",
             DeprecationWarning,
         )
-
-    plot, tmp = _process_plot_arguments(
+    plot, tmp, link_width_scaling = _process_plot_arguments(
         g, title, notebook, euclidean, link_kwargs, node_kwargs
     )
     show_flows = True
@@ -230,7 +237,7 @@ def show_network(
 
     max_width_bokeh, max_width_coords = get_max_edge_width(
         tmp,
-        parameters.visualization.link_width_scaling,
+        link_width_scaling,
         parameters.visualization.plot_size,
     )
 
@@ -243,7 +250,7 @@ def show_network(
         flows,
         time_step=1,
         highlight_links=highlight_links,
-        patch_ratio=3,
+        patch_ratio=parameters.visualization.link_width_min_max_ratio,
     )
     edge_source = _edge_cds(tmp, c, flows, x, y, **link_kwargs)
     edge_renderer = plot.add_glyph(
@@ -297,7 +304,10 @@ def show_network(
         )
         plot.add_tools(node_hover)
     plot.add_tools(edge_hover)
-    show(plot)
+    if not return_plot:
+        show(plot)
+    else:
+        return plot
 
 
 def show_link_od_flows(g: nx.DiGraph, od_flows, **kwargs):
@@ -348,6 +358,7 @@ def show_dynamic_network(
     title=None,
     notebook=False,
     show_nodes=True,
+    return_plot=False,
 ):
     """
     Visualizing a network with dynamic attributes in a .html.
@@ -368,7 +379,7 @@ def show_dynamic_network(
     highlight_links: numpy.ndarray, optional
         int, 1D or 2D - links to highlight
     highlight_nodes: numpy.ndarray, optional
-        int, 1D or 2D - links to highlight
+        int, 1D or 2D - nodes to highlight
     euclidean: bool, optional
         set to True if coordinates in graph are euclidean.
     toy_network: bool, optional
@@ -378,6 +389,8 @@ def show_dynamic_network(
         set to True if the plot should be rendered in a notebook.
     show_nodes: bool, optional
         whether to render nodes
+    return_plot: bool, optional
+        set to True if the plot object should be returned instead of showing it.
 
     Examples
     --------
@@ -417,7 +430,7 @@ def show_dynamic_network(
             DeprecationWarning,
         )
 
-    plot, tmp = _process_plot_arguments(
+    plot, tmp, link_width_scaling = _process_plot_arguments(
         g, title, notebook, euclidean, link_kwargs, node_kwargs
     )
     if flows is None:
@@ -467,7 +480,7 @@ def show_dynamic_network(
     max_flow = min(np.max(flows), 8000)  # weeding out numerical errors
     max_width_bokeh, max_width_coords = get_max_edge_width(
         tmp,
-        parameters.visualization.link_width_scaling,
+        link_width_scaling,
         parameters.visualization.plot_size,
     )
     # calculate all colors and coordinates for the different time dependent flows
@@ -619,7 +632,10 @@ def show_dynamic_network(
     if show_nodes:
         time_slider.js_on_change("value", node_call_back)
     layout = row(plot, column(text_input, Spacer(height=40), time_slider))
-    show(layout)
+    if return_plot:
+        return layout
+    else:
+        show(layout)
 
 
 def get_max_edge_width(g, scaling, plot_size):
@@ -631,7 +647,15 @@ def get_max_edge_width(g, scaling, plot_size):
     return max_width_bokeh, max_width_coords
 
 
-def show_demand(g, title=None, notebook=False, euclidean=False, toy_network=False):
+def show_demand(
+    g,
+    title=None,
+    notebook=False,
+    euclidean=False,
+    toy_network=False,
+    highlight_nodes=[],
+    return_plot=False,
+):
     """
 
     visualize demand on a map
@@ -646,6 +670,10 @@ def show_demand(g, title=None, notebook=False, euclidean=False, toy_network=Fals
         set to True, if 'x_coord' and 'y_coord' in g are euclidean.
     toy_network: bool, optional
         deprecated, use euclidean instead
+    highlight_nodes: numpy.ndarray or list, optional
+        int, 1D - nodes to highlight
+    return_plot: bool, optional
+        set to True if the plot object should be returned instead of showing it.
 
     Examples
     --------
@@ -698,6 +726,7 @@ def show_demand(g, title=None, notebook=False, euclidean=False, toy_network=Fals
         )
         tile_provider = get_provider(Vendors.CARTODBPOSITRON_RETINA)
         plot.add_tile(tile_provider)
+        link_width_scaling = parameters.visualization.link_width_scaling
     else:
         tmp = (
             g  # projection not needed for toy networks, coordinates are plain
@@ -709,10 +738,11 @@ def show_demand(g, title=None, notebook=False, euclidean=False, toy_network=Fals
             aspect_ratio=1,
             toolbar_location="below",
         )
+        link_width_scaling = parameters.visualization.link_width_scaling_euclidean
     plot.title.text = title
     max_width_bokeh, max_width_coords = get_max_edge_width(
         tmp,
-        parameters.visualization.link_width_scaling,
+        link_width_scaling,
         parameters.visualization.plot_size,
     )
     min_width_coords = max_width_coords / 10
@@ -725,20 +755,27 @@ def show_demand(g, title=None, notebook=False, euclidean=False, toy_network=Fals
             width_coords = min_width_coords + (max_width_coords - min_width_coords) * (
                 flow / max_flow
             )
-            ls, para_ls = __linestring_from_node_cords(
-                [
-                    [tmp.nodes[u]["x"], tmp.nodes[u]["y"]],
-                    [tmp.nodes[v]["x"], tmp.nodes[v]["y"]],
-                ],
+            x, y = __build_patch_buffered(
+                tmp.nodes[u]["x"],
+                tmp.nodes[u]["y"],
+                tmp.nodes[v]["x"],
+                tmp.nodes[v]["y"],
+                data,
                 width_coords,
             )
-            (x1, y1, x2, y2) = ls.xy + para_ls.xy
-            x = x2 + x1
-            y = y2 + y1
-            x_list.append(list(x))
-            y_list.append(list(y))
+            x_list.append(x)
+            y_list.append(y)
+
+    nodes_to_highlight = np.full(tmp.number_of_nodes(), False)
+    nodes_to_highlight[highlight_nodes] = True
+    node_colors = [
+        node_highlight_color if nodes_to_highlight[idx] else node_color
+        for idx in list(tmp.nodes.keys())
+    ]
+
     node_source = ColumnDataSource(
         data=dict(
+            color=node_colors,
             x=[x for _, x in tmp.nodes.data("x")],
             y=[y for _, y in tmp.nodes.data("y")],
             centroid_id=list(tmp.nodes.keys()),
@@ -760,6 +797,7 @@ def show_demand(g, title=None, notebook=False, euclidean=False, toy_network=Fals
             x="x",
             y="y",
             size=node_size * 2,
+            fill_color="color",
             line_color="black",
             line_alpha=0.4,
             fill_alpha=0.7,
@@ -783,7 +821,10 @@ def show_demand(g, title=None, notebook=False, euclidean=False, toy_network=Fals
     text_input = TextInput(title="Add new graph title", value="")
     text_input.js_link("value", plot.title, "text")
     layout = row(plot, text_input)
-    show(layout)
+    if return_plot:
+        return plot
+    else:
+        show(layout)
 
 
 def _node_cds(g, highlight_nodes=np.array([]), **kwargs):
@@ -835,10 +876,10 @@ def _get_colors_and_coords(
     flows,
     time_step,
     highlight_links: object = np.array([]),
-    patch_ratio=8,
+    patch_ratio=parameters.visualization.link_width_min_max_ratio,
 ):
     nr_of_colors = len(traffic_cm)
-    min_width_coords = max_width_coords / patch_ratio
+    min_width_coords = max_width_coords * patch_ratio
     if (
         max_flow == 0
     ):  # geometries cannot be computed, may sometimes happen in debugging.
@@ -861,12 +902,11 @@ def _get_colors_and_coords(
             ]
         except IndexError:
             color = traffic_cm[-1]  # flow larger than capacity!
-            flow = 0
+            flow = data["capacity"]
         except KeyError:  # capacity or flow not defined
             color = traffic_cm[0]
             flow = 0
         colors.append(color)
-        loaded = 0
         try:
             if flow > 0:
                 loaded = 1
@@ -885,47 +925,16 @@ def _get_colors_and_coords(
             width_coords = min_width_coords
             # width_bokeh = min_width_bokeh
         # edge_dict['width'].append(width_bokeh)
-        if "geometry" in data:
-            ls = data["geometry"]
-            assert isinstance(ls, LineString)
-            para_ls = ls.parallel_offset(width_coords * 1)
-        else:
-            ls, para_ls = __linestring_from_node_cords(
-                [
-                    [g.nodes[u]["x"], g.nodes[u]["y"]],
-                    [g.nodes[v]["x"], g.nodes[v]["y"]],
-                ],
-                width_coords,
-            )
 
-        try:
-            (x1, y1, x2, y2) = ls.xy + para_ls.xy
-            x = x2 + x1
-            y = y2 + y1
-        except (
-            AttributeError,
-            NotImplementedError,
-        ):  # Attributeerror: weird error due to i'll defined line
-            # string .. - dig deeper if I have more time on my hands - probably an
-            # error in osmnx line string
-            # creation
-            # Notimplemented Error - original Linestring is cut into multiple pieces
-            # by parallel offset -
-            # hence ls is MultiLineString - if the line string has very sharp corners
-            # the offset will stop working
-            # properly, we just use a straight Line connection in that case
-            ls, para_ls = __linestring_from_node_cords(
-                [
-                    [g.nodes[u]["x"], g.nodes[u]["y"]],
-                    [g.nodes[v]["x"], g.nodes[v]["y"]],
-                ],
-                width_coords,
-            )
-            (x1, y1, x2, y2) = ls.xy + para_ls.xy
-            x = x1 + x2
-            y = y1 + y2
-        x_list.append(list(x))
-        y_list.append(list(y))
+        x1, y1, x2, y2 = (
+            g.nodes[u]["x"],
+            g.nodes[u]["y"],
+            g.nodes[v]["x"],
+            g.nodes[v]["y"],
+        )
+        x, y = __build_patch_buffered(x1, y1, x2, y2, data, width_coords)
+        x_list.append(x)
+        y_list.append(y)
 
     if type(highlight_links) == np.ndarray or (
         type(highlight_links) == list
@@ -954,6 +963,20 @@ def _get_colors_and_coords(
     return colors, x_list, y_list
 
 
-def __linestring_from_node_cords(coord_list, width_coords):
-    ls = LineString(coord_list)
-    return ls, ls.parallel_offset(1 * width_coords)
+def __build_patch_buffered(x1, y1, x2, y2, data, width_coords):
+    # buffers around the line in one direction.
+    # returns a list of x and y coordinates that form the boundary of the generated
+    # polygon.
+
+    if "geometry" in data:
+        ls = data["geometry"]
+    else:
+        ls = LineString([[x1, y1], [x2, y2]])
+    poly = ls.buffer(-width_coords, single_sided=True)
+    if isinstance(poly, MultiPolygon) or len(poly.interiors) > 0:  # Lines with very
+        # steep curves or self-intersections yield either multiple polygons or
+        # polygons with holes, in either case we take the straight line instead.
+        # TODO: investigate support for MultiPolygons with holes in Bokeh
+        ls = LineString([[x1, y1], [x2, y2]])
+        poly = ls.buffer(-width_coords, single_sided=True)
+    return poly.exterior.xy[0].tolist(), poly.exterior.xy[1].tolist()
